JOB_STATUS_ERROR_MAP = {
    3: "内部错误",
    100: "导入文档已加密",
    101: "内部错误",
    102: "内部错误",
    103: "内部错误",
    104: "租户容量不足",
    105: "文件夹节点太多",
    106: "内部错误",
    108: "处理超时",
    109: "内部错误",
    110: "无权限",
    112: "格式不支持",
    113: "office格式不支持",
    114: "内部错误",
    115: "导入文件过大",
    116: "当前身份无导入至该文件夹的权限",
    117: "目录已删除",
    118: "导入文件和任务指定后缀不匹配",
    119: "目录不存在",
    120: "导入文件和任务指定文件类型不匹配",
    121: "导入文件已过期",
    122: "创建副本中禁止导出",
    129: "文件格式损坏。请另存为新文件后导入",
    5000: "内部错误",
    7000: "docx block 数量超过系统上限",
    7001: "docx block 层级超过系统上线",
    7002: "docx block 大小超过系统上限",
}
